@@ -95,8 +95,8 @@ char IpaqModel = -1;
 #define SYS_STATE_ON  0
 #define SYS_STATE_OFF 4
 static char *SYS_BRIGHTNESS = NULL;
+static char *SYS_MAXBRIGHTNESS = NULL;
 static char *SYS_POWER = NULL;
-static char *SYS_LCDPOWER = NULL;
 
 GtkWidget *slider_window;
 GtkWidget *window, *slider;
@@ -144,9 +144,8 @@ setup_sysclass(void)
 	bl_dev = get_sysclass_bl();
 	
 	SYS_BRIGHTNESS = g_strdup_printf("%s/brightness", bl_dev);
+	SYS_MAXBRIGHTNESS = g_strdup_printf("%s/max_brightness", bl_dev);
 	SYS_POWER = g_strdup_printf("%s/power", bl_dev);
-	SYS_LCDPOWER = g_strdup_printf("/sys/class/lcd/%s/power", 
-	                               strrchr(bl_dev, '/') + 1);
 }
 
 static t_platform
@@ -179,11 +178,27 @@ int
 sysclass_set_level(int level)
 {
   FILE *f_light;
+  FILE *f_max;
+  int val, maxlevel;
   
+  if ( level > 255 ) level = 255;
+  if ( level < 1 ) level = 1;
+
+  f_max = fopen(SYS_MAXBRIGHTNESS, "r");
+  if (f_max != NULL)
+  {
+    fscanf(f_max,"%d", &maxlevel);
+    fclose(f_max);
+  }
+  val = ( level == 1 ) ? 1 : ( level * maxlevel ) / 255;
+  if (val > maxlevel)
+  {
+    val = maxlevel;
+  }
   f_light = fopen(SYS_BRIGHTNESS, "w");
   if (f_light != NULL)
   {
-    fprintf(f_light,"%d\n", level * 4);
+    fprintf(f_light,"%d\n", val);
   	fclose(f_light);
   }
   else
@@ -195,12 +210,6 @@ sysclass_set_level(int level)
     fprintf(f_light,"%d\n",  level ? SYS_STATE_ON : SYS_STATE_OFF);
   	fclose(f_light);
   }
-  f_light = fopen(SYS_LCDPOWER, "w");
-  if (f_light != NULL)
-  {
-    fprintf(f_light,"%d\n",  level ? SYS_STATE_ON : SYS_STATE_OFF);
-  	fclose(f_light);
-  }
   
   return level;
 }
@@ -209,14 +218,27 @@ int
 sysclass_get_level(void)
 {
   FILE *f_light;
-  int level = 0;
+  FILE *f_max;
+  double level, maxlevel, factor;
   
+  f_max = fopen(SYS_MAXBRIGHTNESS, "r");
+  if (f_max != NULL)
+  {
+    fscanf(f_max,"%d", &maxlevel);
+    fclose(f_max);
+  }
+  factor = 255/maxlevel;
   f_light = fopen(SYS_BRIGHTNESS, "r");
   if (f_light != NULL)
   {
   	fscanf(f_light,"%d", &level);
   	fclose(f_light);
-	return level / 4;
+    level = level * factor;
+    if (level > 255)
+    {
+      level = 255;
+    }
+	return (int)level;
   }
   return -1;
 }  
@@ -629,8 +651,6 @@ external_event(GtkWindow *window, GdkEventConfigure *event, gpointer user_data)
     gtk_widget_shape_combine_mask (GTK_WIDGET(window), bitmap, 1, 0);
     gdk_bitmap_unref (bitmap);
     gtk_image_set_from_pixbuf(GTK_IMAGE(icon),dbuf);
-	/* make sure we want to resize all the time */
-	gtk_widget_set_size_request(GTK_WIDGET(window), size , size);
   }
   return FALSE;
 }
@@ -662,9 +682,7 @@ main (int argc, char **argv)
 
   window = gtk_plug_new (0);
   gtk_window_set_resizable(GTK_WINDOW(window),TRUE);
-  gtk_widget_set_usize (window, 16, 16);
-   /* this makes it scale up to 48pixels child size if possible */	
-  gtk_widget_set_size_request(window,50,50);
+    
   gtk_widget_realize (window);
 
   if (gpe_load_icons (my_icons) == FALSE) {
